# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.invoice_item_api import InvoiceItemApi  # noqa: E501
from killbill.rest import ApiException


class TestInvoiceItemApi(unittest.TestCase):
    """InvoiceItemApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.invoice_item_api.InvoiceItemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_invoice_item_custom_fields(self):
        """Test case for create_invoice_item_custom_fields

        Add custom fields to invoice item  # noqa: E501
        """
        pass

    def test_create_invoice_item_tags(self):
        """Test case for create_invoice_item_tags

        Add tags to invoice item  # noqa: E501
        """
        pass

    def test_delete_invoice_item_custom_fields(self):
        """Test case for delete_invoice_item_custom_fields

        Remove custom fields from invoice item  # noqa: E501
        """
        pass

    def test_delete_invoice_item_tags(self):
        """Test case for delete_invoice_item_tags

        Remove tags from invoice item  # noqa: E501
        """
        pass

    def test_get_invoice_item_audit_logs_with_history(self):
        """Test case for get_invoice_item_audit_logs_with_history

        Retrieve invoice item audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_invoice_item_custom_fields(self):
        """Test case for get_invoice_item_custom_fields

        Retrieve invoice item custom fields  # noqa: E501
        """
        pass

    def test_get_invoice_item_tags(self):
        """Test case for get_invoice_item_tags

        Retrieve invoice item tags  # noqa: E501
        """
        pass

    def test_modify_invoice_item_custom_fields(self):
        """Test case for modify_invoice_item_custom_fields

        Modify custom fields to invoice item  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from killbill.api_client import ApiClient


class BundleApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_bundle_blocking_state(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Block a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_bundle_blocking_state(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BlockingState body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param date requested_date:
        :param list[str] plugin_property:
        :return: list[BlockingState]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_bundle_blocking_state_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_bundle_blocking_state_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def add_bundle_blocking_state_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Block a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_bundle_blocking_state_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BlockingState body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param date requested_date:
        :param list[str] plugin_property:
        :return: list[BlockingState]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment', 'requested_date', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_bundle_blocking_state" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_bundle_blocking_state`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `add_bundle_blocking_state`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `add_bundle_blocking_state`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/block', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BlockingState]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_bundle_custom_fields(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Add custom fields to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bundle_custom_fields(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[CustomField] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: list[CustomField]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def create_bundle_custom_fields_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Add custom fields to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[CustomField] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: list[CustomField]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_bundle_custom_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_bundle_custom_fields`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `create_bundle_custom_fields`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `create_bundle_custom_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/customFields', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CustomField]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_bundle_tags(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Add tags to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bundle_tags(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: list[Tag]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_bundle_tags_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_bundle_tags_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def create_bundle_tags_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Add tags to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bundle_tags_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: list[Tag]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_bundle_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_bundle_tags`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `create_bundle_tags`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `create_bundle_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/tags', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Tag]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_bundle_custom_fields(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Remove custom fields from bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bundle_custom_fields(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param list[str] custom_field:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_bundle_custom_fields_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_bundle_custom_fields_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def delete_bundle_custom_fields_with_http_info(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Remove custom fields from bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bundle_custom_fields_with_http_info(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param list[str] custom_field:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'x_killbill_created_by', 'custom_field', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_bundle_custom_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `delete_bundle_custom_fields`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `delete_bundle_custom_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'custom_field' in params:
            query_params.append(('customField', params['custom_field']))  # noqa: E501
            collection_formats['customField'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/customFields', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_bundle_tags(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Remove tags from bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bundle_tags(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param list[str] tag_def:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_bundle_tags_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_bundle_tags_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def delete_bundle_tags_with_http_info(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Remove tags from bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bundle_tags_with_http_info(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param list[str] tag_def:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'x_killbill_created_by', 'tag_def', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_bundle_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `delete_bundle_tags`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `delete_bundle_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'tag_def' in params:
            query_params.append(('tagDef', params['tag_def']))  # noqa: E501
            collection_formats['tagDef'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/tags', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundle(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve a bundle by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str audit:
        :return: Bundle
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundle_with_http_info(bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bundle_with_http_info(bundle_id, **kwargs)  # noqa: E501
            return data

    def get_bundle_with_http_info(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve a bundle by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_with_http_info(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str audit:
        :return: Bundle
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundle" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `get_bundle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Bundle',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundle_audit_logs_with_history(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle audit logs with history by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_audit_logs_with_history(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :return: list[AuditLog]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundle_audit_logs_with_history_with_http_info(bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bundle_audit_logs_with_history_with_http_info(bundle_id, **kwargs)  # noqa: E501
            return data

    def get_bundle_audit_logs_with_history_with_http_info(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle audit logs with history by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_audit_logs_with_history_with_http_info(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :return: list[AuditLog]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundle_audit_logs_with_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `get_bundle_audit_logs_with_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/auditLogsWithHistory', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AuditLog]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundle_by_key(self, external_key, **kwargs):  # noqa: E501
        """Retrieve a bundle by external key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_by_key(external_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key: (required)
        :param bool included_deleted:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundle_by_key_with_http_info(external_key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bundle_by_key_with_http_info(external_key, **kwargs)  # noqa: E501
            return data

    def get_bundle_by_key_with_http_info(self, external_key, **kwargs):  # noqa: E501
        """Retrieve a bundle by external key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_by_key_with_http_info(external_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_key: (required)
        :param bool included_deleted:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_key', 'included_deleted', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundle_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_key' is set
        if ('external_key' not in params or
                params['external_key'] is None):
            raise ValueError("Missing the required parameter `external_key` when calling `get_bundle_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'external_key' in params:
            query_params.append(('externalKey', params['external_key']))  # noqa: E501
        if 'included_deleted' in params:
            query_params.append(('includedDeleted', params['included_deleted']))  # noqa: E501
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Bundle]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundle_custom_fields(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle custom fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_custom_fields(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str audit:
        :return: list[CustomField]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundle_custom_fields_with_http_info(bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bundle_custom_fields_with_http_info(bundle_id, **kwargs)  # noqa: E501
            return data

    def get_bundle_custom_fields_with_http_info(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle custom fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_custom_fields_with_http_info(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str audit:
        :return: list[CustomField]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundle_custom_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `get_bundle_custom_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/customFields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CustomField]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundle_tags(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle tags  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_tags(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param bool included_deleted:
        :param str audit:
        :return: list[Tag]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundle_tags_with_http_info(bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bundle_tags_with_http_info(bundle_id, **kwargs)  # noqa: E501
            return data

    def get_bundle_tags_with_http_info(self, bundle_id, **kwargs):  # noqa: E501
        """Retrieve bundle tags  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundle_tags_with_http_info(bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param bool included_deleted:
        :param str audit:
        :return: list[Tag]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'included_deleted', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundle_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `get_bundle_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'included_deleted' in params:
            query_params.append(('includedDeleted', params['included_deleted']))  # noqa: E501
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/tags', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Tag]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bundles(self, **kwargs):  # noqa: E501
        """List bundles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bundles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_bundles_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_bundles_with_http_info(self, **kwargs):  # noqa: E501
        """List bundles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bundles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bundles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/pagination', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Bundle]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def modify_bundle_custom_fields(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Modify custom fields to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_bundle_custom_fields(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[CustomField] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.modify_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.modify_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def modify_bundle_custom_fields_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Modify custom fields to bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.modify_bundle_custom_fields_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[CustomField] body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_bundle_custom_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `modify_bundle_custom_fields`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `modify_bundle_custom_fields`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `modify_bundle_custom_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/customFields', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_bundle(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Pause a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_bundle(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param date requested_date:
        :param list[str] plugin_property:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pause_bundle_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.pause_bundle_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def pause_bundle_with_http_info(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Pause a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_bundle_with_http_info(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param date requested_date:
        :param list[str] plugin_property:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'x_killbill_created_by', 'requested_date', 'plugin_property', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_bundle" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `pause_bundle`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `pause_bundle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/pause', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rename_external_key(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Update a bundle externalKey  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_external_key(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Bundle body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.rename_external_key_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rename_external_key_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def rename_external_key_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Update a bundle externalKey  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rename_external_key_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Bundle body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rename_external_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `rename_external_key`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `rename_external_key`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `rename_external_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/renameKey', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_bundle(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Resume a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_bundle(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param date requested_date:
        :param list[str] plugin_property:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_bundle_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_bundle_with_http_info(bundle_id, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def resume_bundle_with_http_info(self, bundle_id, x_killbill_created_by, **kwargs):  # noqa: E501
        """Resume a bundle  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_bundle_with_http_info(bundle_id, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bundle_id: (required)
        :param str x_killbill_created_by: (required)
        :param date requested_date:
        :param list[str] plugin_property:
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bundle_id', 'x_killbill_created_by', 'requested_date', 'plugin_property', 'x_killbill_reason', 'x_killbill_comment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_bundle" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `resume_bundle`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `resume_bundle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}/resume', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_bundles(self, search_key, **kwargs):  # noqa: E501
        """Search bundles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_bundles(search_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str search_key: (required)
        :param int offset:
        :param int limit:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_bundles_with_http_info(search_key, **kwargs)  # noqa: E501
        else:
            (data) = self.search_bundles_with_http_info(search_key, **kwargs)  # noqa: E501
            return data

    def search_bundles_with_http_info(self, search_key, **kwargs):  # noqa: E501
        """Search bundles  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_bundles_with_http_info(search_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str search_key: (required)
        :param int offset:
        :param int limit:
        :param str audit:
        :return: list[Bundle]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['search_key', 'offset', 'limit', 'audit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_bundles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'search_key' is set
        if ('search_key' not in params or
                params['search_key'] is None):
            raise ValueError("Missing the required parameter `search_key` when calling `search_bundles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'search_key' in params:
            path_params['searchKey'] = params['search_key']  # noqa: E501

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'audit' in params:
            query_params.append(('audit', params['audit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/search/{searchKey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Bundle]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def transfer_bundle(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Transfer a bundle to another account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.transfer_bundle(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Bundle body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param date requested_date:
        :param str billing_policy:
        :param list[str] plugin_property:
        :return: Bundle
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.transfer_bundle_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
        else:
            (data) = self.transfer_bundle_with_http_info(body, x_killbill_created_by, bundle_id, **kwargs)  # noqa: E501
            return data

    def transfer_bundle_with_http_info(self, body, x_killbill_created_by, bundle_id, **kwargs):  # noqa: E501
        """Transfer a bundle to another account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.transfer_bundle_with_http_info(body, x_killbill_created_by, bundle_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Bundle body: (required)
        :param str x_killbill_created_by: (required)
        :param str bundle_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param date requested_date:
        :param str billing_policy:
        :param list[str] plugin_property:
        :return: Bundle
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'bundle_id', 'x_killbill_reason', 'x_killbill_comment', 'requested_date', 'billing_policy', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method transfer_bundle" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `transfer_bundle`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `transfer_bundle`")  # noqa: E501
        # verify the required parameter 'bundle_id' is set
        if ('bundle_id' not in params or
                params['bundle_id'] is None):
            raise ValueError("Missing the required parameter `bundle_id` when calling `transfer_bundle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'bundle_id' in params:
            path_params['bundleId'] = params['bundle_id']  # noqa: E501

        query_params = []
        if 'requested_date' in params:
            query_params.append(('requestedDate', params['requested_date']))  # noqa: E501
        if 'billing_policy' in params:
            query_params.append(('billingPolicy', params['billing_policy']))  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/bundles/{bundleId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Bundle',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OverdueStateConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'is_clear_state': 'bool',
        'condition': 'OverdueCondition',
        'external_message': 'str',
        'is_block_changes': 'bool',
        'is_disable_entitlement': 'bool',
        'subscription_cancellation_policy': 'str',
        'auto_reevaluation_interval_days': 'int'
    }

    attribute_map = {
        'name': 'name',
        'is_clear_state': 'isClearState',
        'condition': 'condition',
        'external_message': 'externalMessage',
        'is_block_changes': 'isBlockChanges',
        'is_disable_entitlement': 'isDisableEntitlement',
        'subscription_cancellation_policy': 'subscriptionCancellationPolicy',
        'auto_reevaluation_interval_days': 'autoReevaluationIntervalDays'
    }

    def __init__(self, name=None, is_clear_state=None, condition=None, external_message=None, is_block_changes=None, is_disable_entitlement=None, subscription_cancellation_policy=None, auto_reevaluation_interval_days=None):  # noqa: E501
        """OverdueStateConfig - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._is_clear_state = None
        self._condition = None
        self._external_message = None
        self._is_block_changes = None
        self._is_disable_entitlement = None
        self._subscription_cancellation_policy = None
        self._auto_reevaluation_interval_days = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if is_clear_state is not None:
            self.is_clear_state = is_clear_state
        if condition is not None:
            self.condition = condition
        if external_message is not None:
            self.external_message = external_message
        if is_block_changes is not None:
            self.is_block_changes = is_block_changes
        if is_disable_entitlement is not None:
            self.is_disable_entitlement = is_disable_entitlement
        if subscription_cancellation_policy is not None:
            self.subscription_cancellation_policy = subscription_cancellation_policy
        if auto_reevaluation_interval_days is not None:
            self.auto_reevaluation_interval_days = auto_reevaluation_interval_days

    @property
    def name(self):
        """Gets the name of this OverdueStateConfig.  # noqa: E501


        :return: The name of this OverdueStateConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OverdueStateConfig.


        :param name: The name of this OverdueStateConfig.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_clear_state(self):
        """Gets the is_clear_state of this OverdueStateConfig.  # noqa: E501


        :return: The is_clear_state of this OverdueStateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_clear_state

    @is_clear_state.setter
    def is_clear_state(self, is_clear_state):
        """Sets the is_clear_state of this OverdueStateConfig.


        :param is_clear_state: The is_clear_state of this OverdueStateConfig.  # noqa: E501
        :type: bool
        """

        self._is_clear_state = is_clear_state

    @property
    def condition(self):
        """Gets the condition of this OverdueStateConfig.  # noqa: E501


        :return: The condition of this OverdueStateConfig.  # noqa: E501
        :rtype: OverdueCondition
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this OverdueStateConfig.


        :param condition: The condition of this OverdueStateConfig.  # noqa: E501
        :type: OverdueCondition
        """

        self._condition = condition

    @property
    def external_message(self):
        """Gets the external_message of this OverdueStateConfig.  # noqa: E501


        :return: The external_message of this OverdueStateConfig.  # noqa: E501
        :rtype: str
        """
        return self._external_message

    @external_message.setter
    def external_message(self, external_message):
        """Sets the external_message of this OverdueStateConfig.


        :param external_message: The external_message of this OverdueStateConfig.  # noqa: E501
        :type: str
        """

        self._external_message = external_message

    @property
    def is_block_changes(self):
        """Gets the is_block_changes of this OverdueStateConfig.  # noqa: E501


        :return: The is_block_changes of this OverdueStateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_block_changes

    @is_block_changes.setter
    def is_block_changes(self, is_block_changes):
        """Sets the is_block_changes of this OverdueStateConfig.


        :param is_block_changes: The is_block_changes of this OverdueStateConfig.  # noqa: E501
        :type: bool
        """

        self._is_block_changes = is_block_changes

    @property
    def is_disable_entitlement(self):
        """Gets the is_disable_entitlement of this OverdueStateConfig.  # noqa: E501


        :return: The is_disable_entitlement of this OverdueStateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_disable_entitlement

    @is_disable_entitlement.setter
    def is_disable_entitlement(self, is_disable_entitlement):
        """Sets the is_disable_entitlement of this OverdueStateConfig.


        :param is_disable_entitlement: The is_disable_entitlement of this OverdueStateConfig.  # noqa: E501
        :type: bool
        """

        self._is_disable_entitlement = is_disable_entitlement

    @property
    def subscription_cancellation_policy(self):
        """Gets the subscription_cancellation_policy of this OverdueStateConfig.  # noqa: E501


        :return: The subscription_cancellation_policy of this OverdueStateConfig.  # noqa: E501
        :rtype: str
        """
        return self._subscription_cancellation_policy

    @subscription_cancellation_policy.setter
    def subscription_cancellation_policy(self, subscription_cancellation_policy):
        """Sets the subscription_cancellation_policy of this OverdueStateConfig.


        :param subscription_cancellation_policy: The subscription_cancellation_policy of this OverdueStateConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["END_OF_TERM", "IMMEDIATE", "NONE"]  # noqa: E501
        if subscription_cancellation_policy not in allowed_values:
            raise ValueError(
                "Invalid value for `subscription_cancellation_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(subscription_cancellation_policy, allowed_values)
            )

        self._subscription_cancellation_policy = subscription_cancellation_policy

    @property
    def auto_reevaluation_interval_days(self):
        """Gets the auto_reevaluation_interval_days of this OverdueStateConfig.  # noqa: E501


        :return: The auto_reevaluation_interval_days of this OverdueStateConfig.  # noqa: E501
        :rtype: int
        """
        return self._auto_reevaluation_interval_days

    @auto_reevaluation_interval_days.setter
    def auto_reevaluation_interval_days(self, auto_reevaluation_interval_days):
        """Sets the auto_reevaluation_interval_days of this OverdueStateConfig.


        :param auto_reevaluation_interval_days: The auto_reevaluation_interval_days of this OverdueStateConfig.  # noqa: E501
        :type: int
        """

        self._auto_reevaluation_interval_days = auto_reevaluation_interval_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OverdueStateConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OverdueStateConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvoicePayment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'target_invoice_id': 'str',
        'account_id': 'str',
        'payment_id': 'str',
        'payment_number': 'str',
        'payment_external_key': 'str',
        'auth_amount': 'float',
        'captured_amount': 'float',
        'purchased_amount': 'float',
        'refunded_amount': 'float',
        'credited_amount': 'float',
        'currency': 'str',
        'payment_method_id': 'str',
        'transactions': 'list[PaymentTransaction]',
        'payment_attempts': 'list[PaymentAttempt]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'target_invoice_id': 'targetInvoiceId',
        'account_id': 'accountId',
        'payment_id': 'paymentId',
        'payment_number': 'paymentNumber',
        'payment_external_key': 'paymentExternalKey',
        'auth_amount': 'authAmount',
        'captured_amount': 'capturedAmount',
        'purchased_amount': 'purchasedAmount',
        'refunded_amount': 'refundedAmount',
        'credited_amount': 'creditedAmount',
        'currency': 'currency',
        'payment_method_id': 'paymentMethodId',
        'transactions': 'transactions',
        'payment_attempts': 'paymentAttempts',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, target_invoice_id=None, account_id=None, payment_id=None, payment_number=None, payment_external_key=None, auth_amount=None, captured_amount=None, purchased_amount=None, refunded_amount=None, credited_amount=None, currency=None, payment_method_id=None, transactions=None, payment_attempts=None, audit_logs=None):  # noqa: E501
        """InvoicePayment - a model defined in Swagger"""  # noqa: E501
        self._target_invoice_id = None
        self._account_id = None
        self._payment_id = None
        self._payment_number = None
        self._payment_external_key = None
        self._auth_amount = None
        self._captured_amount = None
        self._purchased_amount = None
        self._refunded_amount = None
        self._credited_amount = None
        self._currency = None
        self._payment_method_id = None
        self._transactions = None
        self._payment_attempts = None
        self._audit_logs = None
        self.discriminator = None
        if target_invoice_id is not None:
            self.target_invoice_id = target_invoice_id
        if account_id is not None:
            self.account_id = account_id
        if payment_id is not None:
            self.payment_id = payment_id
        if payment_number is not None:
            self.payment_number = payment_number
        if payment_external_key is not None:
            self.payment_external_key = payment_external_key
        if auth_amount is not None:
            self.auth_amount = auth_amount
        if captured_amount is not None:
            self.captured_amount = captured_amount
        if purchased_amount is not None:
            self.purchased_amount = purchased_amount
        if refunded_amount is not None:
            self.refunded_amount = refunded_amount
        if credited_amount is not None:
            self.credited_amount = credited_amount
        if currency is not None:
            self.currency = currency
        if payment_method_id is not None:
            self.payment_method_id = payment_method_id
        if transactions is not None:
            self.transactions = transactions
        if payment_attempts is not None:
            self.payment_attempts = payment_attempts
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def target_invoice_id(self):
        """Gets the target_invoice_id of this InvoicePayment.  # noqa: E501


        :return: The target_invoice_id of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._target_invoice_id

    @target_invoice_id.setter
    def target_invoice_id(self, target_invoice_id):
        """Sets the target_invoice_id of this InvoicePayment.


        :param target_invoice_id: The target_invoice_id of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._target_invoice_id = target_invoice_id

    @property
    def account_id(self):
        """Gets the account_id of this InvoicePayment.  # noqa: E501


        :return: The account_id of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this InvoicePayment.


        :param account_id: The account_id of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def payment_id(self):
        """Gets the payment_id of this InvoicePayment.  # noqa: E501


        :return: The payment_id of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this InvoicePayment.


        :param payment_id: The payment_id of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._payment_id = payment_id

    @property
    def payment_number(self):
        """Gets the payment_number of this InvoicePayment.  # noqa: E501


        :return: The payment_number of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._payment_number

    @payment_number.setter
    def payment_number(self, payment_number):
        """Sets the payment_number of this InvoicePayment.


        :param payment_number: The payment_number of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._payment_number = payment_number

    @property
    def payment_external_key(self):
        """Gets the payment_external_key of this InvoicePayment.  # noqa: E501


        :return: The payment_external_key of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._payment_external_key

    @payment_external_key.setter
    def payment_external_key(self, payment_external_key):
        """Sets the payment_external_key of this InvoicePayment.


        :param payment_external_key: The payment_external_key of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._payment_external_key = payment_external_key

    @property
    def auth_amount(self):
        """Gets the auth_amount of this InvoicePayment.  # noqa: E501


        :return: The auth_amount of this InvoicePayment.  # noqa: E501
        :rtype: float
        """
        return self._auth_amount

    @auth_amount.setter
    def auth_amount(self, auth_amount):
        """Sets the auth_amount of this InvoicePayment.


        :param auth_amount: The auth_amount of this InvoicePayment.  # noqa: E501
        :type: float
        """

        self._auth_amount = auth_amount

    @property
    def captured_amount(self):
        """Gets the captured_amount of this InvoicePayment.  # noqa: E501


        :return: The captured_amount of this InvoicePayment.  # noqa: E501
        :rtype: float
        """
        return self._captured_amount

    @captured_amount.setter
    def captured_amount(self, captured_amount):
        """Sets the captured_amount of this InvoicePayment.


        :param captured_amount: The captured_amount of this InvoicePayment.  # noqa: E501
        :type: float
        """

        self._captured_amount = captured_amount

    @property
    def purchased_amount(self):
        """Gets the purchased_amount of this InvoicePayment.  # noqa: E501


        :return: The purchased_amount of this InvoicePayment.  # noqa: E501
        :rtype: float
        """
        return self._purchased_amount

    @purchased_amount.setter
    def purchased_amount(self, purchased_amount):
        """Sets the purchased_amount of this InvoicePayment.


        :param purchased_amount: The purchased_amount of this InvoicePayment.  # noqa: E501
        :type: float
        """

        self._purchased_amount = purchased_amount

    @property
    def refunded_amount(self):
        """Gets the refunded_amount of this InvoicePayment.  # noqa: E501


        :return: The refunded_amount of this InvoicePayment.  # noqa: E501
        :rtype: float
        """
        return self._refunded_amount

    @refunded_amount.setter
    def refunded_amount(self, refunded_amount):
        """Sets the refunded_amount of this InvoicePayment.


        :param refunded_amount: The refunded_amount of this InvoicePayment.  # noqa: E501
        :type: float
        """

        self._refunded_amount = refunded_amount

    @property
    def credited_amount(self):
        """Gets the credited_amount of this InvoicePayment.  # noqa: E501


        :return: The credited_amount of this InvoicePayment.  # noqa: E501
        :rtype: float
        """
        return self._credited_amount

    @credited_amount.setter
    def credited_amount(self, credited_amount):
        """Sets the credited_amount of this InvoicePayment.


        :param credited_amount: The credited_amount of this InvoicePayment.  # noqa: E501
        :type: float
        """

        self._credited_amount = credited_amount

    @property
    def currency(self):
        """Gets the currency of this InvoicePayment.  # noqa: E501


        :return: The currency of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoicePayment.


        :param currency: The currency of this InvoicePayment.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def payment_method_id(self):
        """Gets the payment_method_id of this InvoicePayment.  # noqa: E501


        :return: The payment_method_id of this InvoicePayment.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, payment_method_id):
        """Sets the payment_method_id of this InvoicePayment.


        :param payment_method_id: The payment_method_id of this InvoicePayment.  # noqa: E501
        :type: str
        """

        self._payment_method_id = payment_method_id

    @property
    def transactions(self):
        """Gets the transactions of this InvoicePayment.  # noqa: E501


        :return: The transactions of this InvoicePayment.  # noqa: E501
        :rtype: list[PaymentTransaction]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this InvoicePayment.


        :param transactions: The transactions of this InvoicePayment.  # noqa: E501
        :type: list[PaymentTransaction]
        """

        self._transactions = transactions

    @property
    def payment_attempts(self):
        """Gets the payment_attempts of this InvoicePayment.  # noqa: E501


        :return: The payment_attempts of this InvoicePayment.  # noqa: E501
        :rtype: list[PaymentAttempt]
        """
        return self._payment_attempts

    @payment_attempts.setter
    def payment_attempts(self, payment_attempts):
        """Sets the payment_attempts of this InvoicePayment.


        :param payment_attempts: The payment_attempts of this InvoicePayment.  # noqa: E501
        :type: list[PaymentAttempt]
        """

        self._payment_attempts = payment_attempts

    @property
    def audit_logs(self):
        """Gets the audit_logs of this InvoicePayment.  # noqa: E501


        :return: The audit_logs of this InvoicePayment.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this InvoicePayment.


        :param audit_logs: The audit_logs of this InvoicePayment.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoicePayment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoicePayment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Invoice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'currency': 'str',
        'status': 'str',
        'credit_adj': 'float',
        'refund_adj': 'float',
        'invoice_id': 'str',
        'invoice_date': 'date',
        'target_date': 'date',
        'invoice_number': 'str',
        'balance': 'float',
        'account_id': 'str',
        'bundle_keys': 'str',
        'credits': 'list[InvoiceItem]',
        'items': 'list[InvoiceItem]',
        'tracking_ids': 'list[str]',
        'is_parent_invoice': 'bool',
        'parent_invoice_id': 'str',
        'parent_account_id': 'str',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'amount': 'amount',
        'currency': 'currency',
        'status': 'status',
        'credit_adj': 'creditAdj',
        'refund_adj': 'refundAdj',
        'invoice_id': 'invoiceId',
        'invoice_date': 'invoiceDate',
        'target_date': 'targetDate',
        'invoice_number': 'invoiceNumber',
        'balance': 'balance',
        'account_id': 'accountId',
        'bundle_keys': 'bundleKeys',
        'credits': 'credits',
        'items': 'items',
        'tracking_ids': 'trackingIds',
        'is_parent_invoice': 'isParentInvoice',
        'parent_invoice_id': 'parentInvoiceId',
        'parent_account_id': 'parentAccountId',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, amount=None, currency=None, status=None, credit_adj=None, refund_adj=None, invoice_id=None, invoice_date=None, target_date=None, invoice_number=None, balance=None, account_id=None, bundle_keys=None, credits=None, items=None, tracking_ids=None, is_parent_invoice=None, parent_invoice_id=None, parent_account_id=None, audit_logs=None):  # noqa: E501
        """Invoice - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._currency = None
        self._status = None
        self._credit_adj = None
        self._refund_adj = None
        self._invoice_id = None
        self._invoice_date = None
        self._target_date = None
        self._invoice_number = None
        self._balance = None
        self._account_id = None
        self._bundle_keys = None
        self._credits = None
        self._items = None
        self._tracking_ids = None
        self._is_parent_invoice = None
        self._parent_invoice_id = None
        self._parent_account_id = None
        self._audit_logs = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if status is not None:
            self.status = status
        if credit_adj is not None:
            self.credit_adj = credit_adj
        if refund_adj is not None:
            self.refund_adj = refund_adj
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if invoice_date is not None:
            self.invoice_date = invoice_date
        if target_date is not None:
            self.target_date = target_date
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if balance is not None:
            self.balance = balance
        if account_id is not None:
            self.account_id = account_id
        if bundle_keys is not None:
            self.bundle_keys = bundle_keys
        if credits is not None:
            self.credits = credits
        if items is not None:
            self.items = items
        if tracking_ids is not None:
            self.tracking_ids = tracking_ids
        if is_parent_invoice is not None:
            self.is_parent_invoice = is_parent_invoice
        if parent_invoice_id is not None:
            self.parent_invoice_id = parent_invoice_id
        if parent_account_id is not None:
            self.parent_account_id = parent_account_id
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def amount(self):
        """Gets the amount of this Invoice.  # noqa: E501


        :return: The amount of this Invoice.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Invoice.


        :param amount: The amount of this Invoice.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this Invoice.  # noqa: E501


        :return: The currency of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Invoice.


        :param currency: The currency of this Invoice.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def status(self):
        """Gets the status of this Invoice.  # noqa: E501


        :return: The status of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Invoice.


        :param status: The status of this Invoice.  # noqa: E501
        :type: str
        """
        allowed_values = ["DRAFT", "COMMITTED", "VOID"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def credit_adj(self):
        """Gets the credit_adj of this Invoice.  # noqa: E501


        :return: The credit_adj of this Invoice.  # noqa: E501
        :rtype: float
        """
        return self._credit_adj

    @credit_adj.setter
    def credit_adj(self, credit_adj):
        """Sets the credit_adj of this Invoice.


        :param credit_adj: The credit_adj of this Invoice.  # noqa: E501
        :type: float
        """

        self._credit_adj = credit_adj

    @property
    def refund_adj(self):
        """Gets the refund_adj of this Invoice.  # noqa: E501


        :return: The refund_adj of this Invoice.  # noqa: E501
        :rtype: float
        """
        return self._refund_adj

    @refund_adj.setter
    def refund_adj(self, refund_adj):
        """Sets the refund_adj of this Invoice.


        :param refund_adj: The refund_adj of this Invoice.  # noqa: E501
        :type: float
        """

        self._refund_adj = refund_adj

    @property
    def invoice_id(self):
        """Gets the invoice_id of this Invoice.  # noqa: E501


        :return: The invoice_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this Invoice.


        :param invoice_id: The invoice_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def invoice_date(self):
        """Gets the invoice_date of this Invoice.  # noqa: E501


        :return: The invoice_date of this Invoice.  # noqa: E501
        :rtype: date
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """Sets the invoice_date of this Invoice.


        :param invoice_date: The invoice_date of this Invoice.  # noqa: E501
        :type: date
        """

        self._invoice_date = invoice_date

    @property
    def target_date(self):
        """Gets the target_date of this Invoice.  # noqa: E501


        :return: The target_date of this Invoice.  # noqa: E501
        :rtype: date
        """
        return self._target_date

    @target_date.setter
    def target_date(self, target_date):
        """Sets the target_date of this Invoice.


        :param target_date: The target_date of this Invoice.  # noqa: E501
        :type: date
        """

        self._target_date = target_date

    @property
    def invoice_number(self):
        """Gets the invoice_number of this Invoice.  # noqa: E501


        :return: The invoice_number of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this Invoice.


        :param invoice_number: The invoice_number of this Invoice.  # noqa: E501
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def balance(self):
        """Gets the balance of this Invoice.  # noqa: E501


        :return: The balance of this Invoice.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this Invoice.


        :param balance: The balance of this Invoice.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def account_id(self):
        """Gets the account_id of this Invoice.  # noqa: E501


        :return: The account_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Invoice.


        :param account_id: The account_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def bundle_keys(self):
        """Gets the bundle_keys of this Invoice.  # noqa: E501


        :return: The bundle_keys of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._bundle_keys

    @bundle_keys.setter
    def bundle_keys(self, bundle_keys):
        """Sets the bundle_keys of this Invoice.


        :param bundle_keys: The bundle_keys of this Invoice.  # noqa: E501
        :type: str
        """

        self._bundle_keys = bundle_keys

    @property
    def credits(self):
        """Gets the credits of this Invoice.  # noqa: E501


        :return: The credits of this Invoice.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._credits

    @credits.setter
    def credits(self, credits):
        """Sets the credits of this Invoice.


        :param credits: The credits of this Invoice.  # noqa: E501
        :type: list[InvoiceItem]
        """

        self._credits = credits

    @property
    def items(self):
        """Gets the items of this Invoice.  # noqa: E501


        :return: The items of this Invoice.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Invoice.


        :param items: The items of this Invoice.  # noqa: E501
        :type: list[InvoiceItem]
        """

        self._items = items

    @property
    def tracking_ids(self):
        """Gets the tracking_ids of this Invoice.  # noqa: E501


        :return: The tracking_ids of this Invoice.  # noqa: E501
        :rtype: list[str]
        """
        return self._tracking_ids

    @tracking_ids.setter
    def tracking_ids(self, tracking_ids):
        """Sets the tracking_ids of this Invoice.


        :param tracking_ids: The tracking_ids of this Invoice.  # noqa: E501
        :type: list[str]
        """

        self._tracking_ids = tracking_ids

    @property
    def is_parent_invoice(self):
        """Gets the is_parent_invoice of this Invoice.  # noqa: E501


        :return: The is_parent_invoice of this Invoice.  # noqa: E501
        :rtype: bool
        """
        return self._is_parent_invoice

    @is_parent_invoice.setter
    def is_parent_invoice(self, is_parent_invoice):
        """Sets the is_parent_invoice of this Invoice.


        :param is_parent_invoice: The is_parent_invoice of this Invoice.  # noqa: E501
        :type: bool
        """

        self._is_parent_invoice = is_parent_invoice

    @property
    def parent_invoice_id(self):
        """Gets the parent_invoice_id of this Invoice.  # noqa: E501


        :return: The parent_invoice_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._parent_invoice_id

    @parent_invoice_id.setter
    def parent_invoice_id(self, parent_invoice_id):
        """Sets the parent_invoice_id of this Invoice.


        :param parent_invoice_id: The parent_invoice_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._parent_invoice_id = parent_invoice_id

    @property
    def parent_account_id(self):
        """Gets the parent_account_id of this Invoice.  # noqa: E501


        :return: The parent_account_id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._parent_account_id

    @parent_account_id.setter
    def parent_account_id(self, parent_account_id):
        """Sets the parent_account_id of this Invoice.


        :param parent_account_id: The parent_account_id of this Invoice.  # noqa: E501
        :type: str
        """

        self._parent_account_id = parent_account_id

    @property
    def audit_logs(self):
        """Gets the audit_logs of this Invoice.  # noqa: E501


        :return: The audit_logs of this Invoice.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this Invoice.


        :param audit_logs: The audit_logs of this Invoice.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Invoice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invoice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.account_api import AccountApi  # noqa: E501
from killbill.rest import ApiException


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.account_api.AccountApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_account_blocking_state(self):
        """Test case for add_account_blocking_state

        Block an account  # noqa: E501
        """
        pass

    def test_add_email(self):
        """Test case for add_email

        Add account email  # noqa: E501
        """
        pass

    def test_close_account(self):
        """Test case for close_account

        Close account  # noqa: E501
        """
        pass

    def test_create_account(self):
        """Test case for create_account

        Create account  # noqa: E501
        """
        pass

    def test_create_account_custom_fields(self):
        """Test case for create_account_custom_fields

        Add custom fields to account  # noqa: E501
        """
        pass

    def test_create_account_tags(self):
        """Test case for create_account_tags

        Add tags to account  # noqa: E501
        """
        pass

    def test_create_payment_method(self):
        """Test case for create_payment_method

        Add a payment method  # noqa: E501
        """
        pass

    def test_delete_account_custom_fields(self):
        """Test case for delete_account_custom_fields

        Remove custom fields from account  # noqa: E501
        """
        pass

    def test_delete_account_tags(self):
        """Test case for delete_account_tags

        Remove tags from account  # noqa: E501
        """
        pass

    def test_get_account(self):
        """Test case for get_account

        Retrieve an account by id  # noqa: E501
        """
        pass

    def test_get_account_audit_logs(self):
        """Test case for get_account_audit_logs

        Retrieve audit logs by account id  # noqa: E501
        """
        pass

    def test_get_account_audit_logs_with_history(self):
        """Test case for get_account_audit_logs_with_history

        Retrieve account audit logs with history by account id  # noqa: E501
        """
        pass

    def test_get_account_bundles(self):
        """Test case for get_account_bundles

        Retrieve bundles for account  # noqa: E501
        """
        pass

    def test_get_account_by_key(self):
        """Test case for get_account_by_key

        Retrieve an account by external key  # noqa: E501
        """
        pass

    def test_get_account_custom_fields(self):
        """Test case for get_account_custom_fields

        Retrieve account custom fields  # noqa: E501
        """
        pass

    def test_get_account_email_audit_logs_with_history(self):
        """Test case for get_account_email_audit_logs_with_history

        Retrieve account email audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_account_tags(self):
        """Test case for get_account_tags

        Retrieve account tags  # noqa: E501
        """
        pass

    def test_get_account_timeline(self):
        """Test case for get_account_timeline

        Retrieve account timeline  # noqa: E501
        """
        pass

    def test_get_accounts(self):
        """Test case for get_accounts

        List accounts  # noqa: E501
        """
        pass

    def test_get_all_custom_fields(self):
        """Test case for get_all_custom_fields

        Retrieve account customFields  # noqa: E501
        """
        pass

    def test_get_all_tags(self):
        """Test case for get_all_tags

        Retrieve account tags  # noqa: E501
        """
        pass

    def test_get_blocking_state_audit_logs_with_history(self):
        """Test case for get_blocking_state_audit_logs_with_history

        Retrieve blocking state audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_blocking_states(self):
        """Test case for get_blocking_states

        Retrieve blocking states for account  # noqa: E501
        """
        pass

    def test_get_children_accounts(self):
        """Test case for get_children_accounts

        List children accounts  # noqa: E501
        """
        pass

    def test_get_emails(self):
        """Test case for get_emails

        Retrieve an account emails  # noqa: E501
        """
        pass

    def test_get_invoice_payments(self):
        """Test case for get_invoice_payments

        Retrieve account invoice payments  # noqa: E501
        """
        pass

    def test_get_invoices_for_account(self):
        """Test case for get_invoices_for_account

        Retrieve account invoices  # noqa: E501
        """
        pass

    def test_get_overdue_account(self):
        """Test case for get_overdue_account

        Retrieve overdue state for account  # noqa: E501
        """
        pass

    def test_get_payment_methods_for_account(self):
        """Test case for get_payment_methods_for_account

        Retrieve account payment methods  # noqa: E501
        """
        pass

    def test_get_payments_for_account(self):
        """Test case for get_payments_for_account

        Retrieve account payments  # noqa: E501
        """
        pass

    def test_modify_account_custom_fields(self):
        """Test case for modify_account_custom_fields

        Modify custom fields to account  # noqa: E501
        """
        pass

    def test_pay_all_invoices(self):
        """Test case for pay_all_invoices

        Trigger a payment for all unpaid invoices  # noqa: E501
        """
        pass

    def test_process_payment(self):
        """Test case for process_payment

        Trigger a payment (authorization, purchase or credit)  # noqa: E501
        """
        pass

    def test_process_payment_by_external_key(self):
        """Test case for process_payment_by_external_key

        Trigger a payment using the account external key (authorization, purchase or credit)  # noqa: E501
        """
        pass

    def test_rebalance_existing_cba_on_account(self):
        """Test case for rebalance_existing_cba_on_account

        Rebalance account CBA  # noqa: E501
        """
        pass

    def test_refresh_payment_methods(self):
        """Test case for refresh_payment_methods

        Refresh account payment methods  # noqa: E501
        """
        pass

    def test_remove_email(self):
        """Test case for remove_email

        Delete email from account  # noqa: E501
        """
        pass

    def test_search_accounts(self):
        """Test case for search_accounts

        Search accounts  # noqa: E501
        """
        pass

    def test_set_default_payment_method(self):
        """Test case for set_default_payment_method

        Set the default payment method  # noqa: E501
        """
        pass

    def test_transfer_child_credit_to_parent(self):
        """Test case for transfer_child_credit_to_parent

        Move a given child credit to the parent level  # noqa: E501
        """
        pass

    def test_update_account(self):
        """Test case for update_account

        Update account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvoicePaymentTransaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_id': 'str',
        'transaction_external_key': 'str',
        'payment_id': 'str',
        'payment_external_key': 'str',
        'transaction_type': 'str',
        'amount': 'float',
        'currency': 'str',
        'effective_date': 'datetime',
        'processed_amount': 'float',
        'processed_currency': 'str',
        'status': 'str',
        'gateway_error_code': 'str',
        'gateway_error_msg': 'str',
        'first_payment_reference_id': 'str',
        'second_payment_reference_id': 'str',
        'properties': 'list[PluginProperty]',
        'is_adjusted': 'bool',
        'adjustments': 'list[InvoiceItem]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'transaction_id': 'transactionId',
        'transaction_external_key': 'transactionExternalKey',
        'payment_id': 'paymentId',
        'payment_external_key': 'paymentExternalKey',
        'transaction_type': 'transactionType',
        'amount': 'amount',
        'currency': 'currency',
        'effective_date': 'effectiveDate',
        'processed_amount': 'processedAmount',
        'processed_currency': 'processedCurrency',
        'status': 'status',
        'gateway_error_code': 'gatewayErrorCode',
        'gateway_error_msg': 'gatewayErrorMsg',
        'first_payment_reference_id': 'firstPaymentReferenceId',
        'second_payment_reference_id': 'secondPaymentReferenceId',
        'properties': 'properties',
        'is_adjusted': 'isAdjusted',
        'adjustments': 'adjustments',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, transaction_id=None, transaction_external_key=None, payment_id=None, payment_external_key=None, transaction_type=None, amount=None, currency=None, effective_date=None, processed_amount=None, processed_currency=None, status=None, gateway_error_code=None, gateway_error_msg=None, first_payment_reference_id=None, second_payment_reference_id=None, properties=None, is_adjusted=None, adjustments=None, audit_logs=None):  # noqa: E501
        """InvoicePaymentTransaction - a model defined in Swagger"""  # noqa: E501
        self._transaction_id = None
        self._transaction_external_key = None
        self._payment_id = None
        self._payment_external_key = None
        self._transaction_type = None
        self._amount = None
        self._currency = None
        self._effective_date = None
        self._processed_amount = None
        self._processed_currency = None
        self._status = None
        self._gateway_error_code = None
        self._gateway_error_msg = None
        self._first_payment_reference_id = None
        self._second_payment_reference_id = None
        self._properties = None
        self._is_adjusted = None
        self._adjustments = None
        self._audit_logs = None
        self.discriminator = None
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if transaction_external_key is not None:
            self.transaction_external_key = transaction_external_key
        if payment_id is not None:
            self.payment_id = payment_id
        if payment_external_key is not None:
            self.payment_external_key = payment_external_key
        if transaction_type is not None:
            self.transaction_type = transaction_type
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if effective_date is not None:
            self.effective_date = effective_date
        if processed_amount is not None:
            self.processed_amount = processed_amount
        if processed_currency is not None:
            self.processed_currency = processed_currency
        if status is not None:
            self.status = status
        if gateway_error_code is not None:
            self.gateway_error_code = gateway_error_code
        if gateway_error_msg is not None:
            self.gateway_error_msg = gateway_error_msg
        if first_payment_reference_id is not None:
            self.first_payment_reference_id = first_payment_reference_id
        if second_payment_reference_id is not None:
            self.second_payment_reference_id = second_payment_reference_id
        if properties is not None:
            self.properties = properties
        if is_adjusted is not None:
            self.is_adjusted = is_adjusted
        if adjustments is not None:
            self.adjustments = adjustments
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def transaction_id(self):
        """Gets the transaction_id of this InvoicePaymentTransaction.  # noqa: E501


        :return: The transaction_id of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this InvoicePaymentTransaction.


        :param transaction_id: The transaction_id of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def transaction_external_key(self):
        """Gets the transaction_external_key of this InvoicePaymentTransaction.  # noqa: E501


        :return: The transaction_external_key of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_external_key

    @transaction_external_key.setter
    def transaction_external_key(self, transaction_external_key):
        """Sets the transaction_external_key of this InvoicePaymentTransaction.


        :param transaction_external_key: The transaction_external_key of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._transaction_external_key = transaction_external_key

    @property
    def payment_id(self):
        """Gets the payment_id of this InvoicePaymentTransaction.  # noqa: E501

        Associated payment id, required when notifying state transitions  # noqa: E501

        :return: The payment_id of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this InvoicePaymentTransaction.

        Associated payment id, required when notifying state transitions  # noqa: E501

        :param payment_id: The payment_id of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._payment_id = payment_id

    @property
    def payment_external_key(self):
        """Gets the payment_external_key of this InvoicePaymentTransaction.  # noqa: E501


        :return: The payment_external_key of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._payment_external_key

    @payment_external_key.setter
    def payment_external_key(self, payment_external_key):
        """Sets the payment_external_key of this InvoicePaymentTransaction.


        :param payment_external_key: The payment_external_key of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._payment_external_key = payment_external_key

    @property
    def transaction_type(self):
        """Gets the transaction_type of this InvoicePaymentTransaction.  # noqa: E501


        :return: The transaction_type of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this InvoicePaymentTransaction.


        :param transaction_type: The transaction_type of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["AUTHORIZE", "CAPTURE", "CHARGEBACK", "CREDIT", "PURCHASE", "REFUND", "VOID"]  # noqa: E501
        if transaction_type not in allowed_values:
            raise ValueError(
                "Invalid value for `transaction_type` ({0}), must be one of {1}"  # noqa: E501
                .format(transaction_type, allowed_values)
            )

        self._transaction_type = transaction_type

    @property
    def amount(self):
        """Gets the amount of this InvoicePaymentTransaction.  # noqa: E501

        Transaction amount, required except for void operations  # noqa: E501

        :return: The amount of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoicePaymentTransaction.

        Transaction amount, required except for void operations  # noqa: E501

        :param amount: The amount of this InvoicePaymentTransaction.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InvoicePaymentTransaction.  # noqa: E501

        Amount currency (account currency unless specified)  # noqa: E501

        :return: The currency of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoicePaymentTransaction.

        Amount currency (account currency unless specified)  # noqa: E501

        :param currency: The currency of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def effective_date(self):
        """Gets the effective_date of this InvoicePaymentTransaction.  # noqa: E501


        :return: The effective_date of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this InvoicePaymentTransaction.


        :param effective_date: The effective_date of this InvoicePaymentTransaction.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    @property
    def processed_amount(self):
        """Gets the processed_amount of this InvoicePaymentTransaction.  # noqa: E501


        :return: The processed_amount of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._processed_amount

    @processed_amount.setter
    def processed_amount(self, processed_amount):
        """Sets the processed_amount of this InvoicePaymentTransaction.


        :param processed_amount: The processed_amount of this InvoicePaymentTransaction.  # noqa: E501
        :type: float
        """

        self._processed_amount = processed_amount

    @property
    def processed_currency(self):
        """Gets the processed_currency of this InvoicePaymentTransaction.  # noqa: E501


        :return: The processed_currency of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._processed_currency

    @processed_currency.setter
    def processed_currency(self, processed_currency):
        """Sets the processed_currency of this InvoicePaymentTransaction.


        :param processed_currency: The processed_currency of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if processed_currency not in allowed_values:
            raise ValueError(
                "Invalid value for `processed_currency` ({0}), must be one of {1}"  # noqa: E501
                .format(processed_currency, allowed_values)
            )

        self._processed_currency = processed_currency

    @property
    def status(self):
        """Gets the status of this InvoicePaymentTransaction.  # noqa: E501

        Transaction status, required for state change notifications  # noqa: E501

        :return: The status of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InvoicePaymentTransaction.

        Transaction status, required for state change notifications  # noqa: E501

        :param status: The status of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["SUCCESS", "UNKNOWN", "PENDING", "PAYMENT_FAILURE", "PLUGIN_FAILURE", "PAYMENT_SYSTEM_OFF"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def gateway_error_code(self):
        """Gets the gateway_error_code of this InvoicePaymentTransaction.  # noqa: E501


        :return: The gateway_error_code of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._gateway_error_code

    @gateway_error_code.setter
    def gateway_error_code(self, gateway_error_code):
        """Sets the gateway_error_code of this InvoicePaymentTransaction.


        :param gateway_error_code: The gateway_error_code of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._gateway_error_code = gateway_error_code

    @property
    def gateway_error_msg(self):
        """Gets the gateway_error_msg of this InvoicePaymentTransaction.  # noqa: E501


        :return: The gateway_error_msg of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._gateway_error_msg

    @gateway_error_msg.setter
    def gateway_error_msg(self, gateway_error_msg):
        """Sets the gateway_error_msg of this InvoicePaymentTransaction.


        :param gateway_error_msg: The gateway_error_msg of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._gateway_error_msg = gateway_error_msg

    @property
    def first_payment_reference_id(self):
        """Gets the first_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501


        :return: The first_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._first_payment_reference_id

    @first_payment_reference_id.setter
    def first_payment_reference_id(self, first_payment_reference_id):
        """Sets the first_payment_reference_id of this InvoicePaymentTransaction.


        :param first_payment_reference_id: The first_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._first_payment_reference_id = first_payment_reference_id

    @property
    def second_payment_reference_id(self):
        """Gets the second_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501


        :return: The second_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._second_payment_reference_id

    @second_payment_reference_id.setter
    def second_payment_reference_id(self, second_payment_reference_id):
        """Sets the second_payment_reference_id of this InvoicePaymentTransaction.


        :param second_payment_reference_id: The second_payment_reference_id of this InvoicePaymentTransaction.  # noqa: E501
        :type: str
        """

        self._second_payment_reference_id = second_payment_reference_id

    @property
    def properties(self):
        """Gets the properties of this InvoicePaymentTransaction.  # noqa: E501


        :return: The properties of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: list[PluginProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this InvoicePaymentTransaction.


        :param properties: The properties of this InvoicePaymentTransaction.  # noqa: E501
        :type: list[PluginProperty]
        """

        self._properties = properties

    @property
    def is_adjusted(self):
        """Gets the is_adjusted of this InvoicePaymentTransaction.  # noqa: E501


        :return: The is_adjusted of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: bool
        """
        return self._is_adjusted

    @is_adjusted.setter
    def is_adjusted(self, is_adjusted):
        """Sets the is_adjusted of this InvoicePaymentTransaction.


        :param is_adjusted: The is_adjusted of this InvoicePaymentTransaction.  # noqa: E501
        :type: bool
        """

        self._is_adjusted = is_adjusted

    @property
    def adjustments(self):
        """Gets the adjustments of this InvoicePaymentTransaction.  # noqa: E501


        :return: The adjustments of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._adjustments

    @adjustments.setter
    def adjustments(self, adjustments):
        """Sets the adjustments of this InvoicePaymentTransaction.


        :param adjustments: The adjustments of this InvoicePaymentTransaction.  # noqa: E501
        :type: list[InvoiceItem]
        """

        self._adjustments = adjustments

    @property
    def audit_logs(self):
        """Gets the audit_logs of this InvoicePaymentTransaction.  # noqa: E501


        :return: The audit_logs of this InvoicePaymentTransaction.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this InvoicePaymentTransaction.


        :param audit_logs: The audit_logs of this InvoicePaymentTransaction.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoicePaymentTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoicePaymentTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.credit_api import CreditApi  # noqa: E501
from killbill.rest import ApiException


class TestCreditApi(unittest.TestCase):
    """CreditApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.credit_api.CreditApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_credits(self):
        """Test case for create_credits

        Create a credit  # noqa: E501
        """
        pass

    def test_get_credit(self):
        """Test case for get_credit

        Retrieve a credit by id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
